get_static_raw

Function get_static_raw 

pub unsafe fn get_static_raw() -> &'static GpioStatic
Get the static data associated with this device node.

Safety

The caller must ensure the returned reference is only used with the matching device from get_instance_raw.